@@ -1,17 +1,21 @@
-/*
- *  Copyright 2001-2009 Internet2
+/**
+ * Licensed to the University Corporation for Advanced Internet
+ * Development, Inc. (UCAID) under one or more contributor license
+ * agreements. See the NOTICE file distributed with this work for
+ * additional information regarding copyright ownership.
  *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * UCAID licenses this file to you under the Apache License,
+ * Version 2.0 (the "License"); you may not use this file except
+ * in compliance with the License. You may obtain a copy of the
+ * License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ * http://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
+ * either express or implied. See the License for the specific
+ * language governing permissions and limitations under the License.
  */
 
 /**
@@ -46,6 +50,11 @@ SAML1MessageDecoder::~SAML1MessageDecoder()
 {
 }
 
+const XMLCh* SAML1MessageDecoder::getProtocolFamily() const
+{
+    return samlconstants::SAML11_PROTOCOL_ENUM;
+}
+
 void SAML1MessageDecoder::extractMessageDetails(
     const XMLObject& message, const GenericRequest& req, const XMLCh* protocol, SecurityPolicy& policy
     ) const
@@ -57,8 +66,8 @@ void SAML1MessageDecoder::extractMessageDetails(
 
     Category& log = Category::getInstance(SAML_LOGCAT".MessageDecoder.SAML1");
 
-    const Request* request=NULL;
-    const Response* response=NULL;
+    const Request* request=nullptr;
+    const Response* response=nullptr;
     if (XMLString::equals(q.getLocalPart(), Request::LOCAL_NAME))
         request = dynamic_cast<const Request*>(&message);
     if (!request && XMLString::equals(q.getLocalPart(), Response::LOCAL_NAME))
