@@ -1,17 +1,21 @@
-/*
- *  Copyright 2001-2009 Internet2
- * 
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+/**
+ * Licensed to the University Corporation for Advanced Internet
+ * Development, Inc. (UCAID) under one or more contributor license
+ * agreements. See the NOTICE file distributed with this work for
+ * additional information regarding copyright ownership.
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ * UCAID licenses this file to you under the Apache License,
+ * Version 2.0 (the "License"); you may not use this file except
+ * in compliance with the License. You may obtain a copy of the
+ * License at
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
+ * either express or implied. See the License for the specific
+ * language governing permissions and limitations under the License.
  */
 
 /**
@@ -54,16 +58,20 @@ namespace opensaml {
                 return false;
             }
 
+            const XMLCh* getProtocolFamily() const {
+                return samlconstants::SAML11_PROTOCOL_ENUM;
+            }
+
             long encode(
                 GenericResponse& genericResponse,
                 XMLObject* xmlObject,
                 const char* destination,
-                const EntityDescriptor* recipient=NULL,
-                const char* relayState=NULL,
-                const ArtifactGenerator* artifactGenerator=NULL,
-                const Credential* credential=NULL,
-                const XMLCh* signatureAlg=NULL,
-                const XMLCh* digestAlg=NULL
+                const EntityDescriptor* recipient=nullptr,
+                const char* relayState=nullptr,
+                const ArtifactGenerator* artifactGenerator=nullptr,
+                const Credential* credential=nullptr,
+                const XMLCh* signatureAlg=nullptr,
+                const XMLCh* digestAlg=nullptr
                 ) const;
         };
 
@@ -104,7 +112,7 @@ long SAML1SOAPEncoder::encode(
     }
 
     bool detachOnFailure = false;
-    DOMElement* rootElement = NULL;
+    DOMElement* rootElement = nullptr;
     
     // Check for a naked Response.
     Response* response = dynamic_cast<Response*>(xmlObject);
@@ -123,7 +131,7 @@ long SAML1SOAPEncoder::encode(
     if (env) {
         if (!response) {
             response = (env->getBody() && env->getBody()->hasChildren()) ?
-                dynamic_cast<Response*>(env->getBody()->getUnknownXMLObjects().front()) : NULL;
+                dynamic_cast<Response*>(env->getBody()->getUnknownXMLObjects().front()) : nullptr;
         }
         try {
             // Now check for signing requirements.
@@ -148,7 +156,7 @@ long SAML1SOAPEncoder::encode(
             
                     // Sign message while marshalling.
                     vector<Signature*> sigs(1,sig);
-                    rootElement = env->marshall((DOMDocument*)NULL,&sigs,credential);
+                    rootElement = env->marshall((DOMDocument*)nullptr,&sigs,credential);
                 }
             }
             else {
