@@ -1,23 +1,27 @@
-/*
- *  Copyright 2001-2007 Internet2
- * 
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+/**
+ * Licensed to the University Corporation for Advanced Internet
+ * Development, Inc. (UCAID) under one or more contributor license
+ * agreements. See the NOTICE file distributed with this work for
+ * additional information regarding copyright ownership.
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ * UCAID licenses this file to you under the Apache License,
+ * Version 2.0 (the "License"); you may not use this file except
+ * in compliance with the License. You may obtain a copy of the
+ * License at
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
+ * either express or implied. See the License for the specific
+ * language governing permissions and limitations under the License.
  */
 
 /**
  * @file saml/saml2/binding/SAML2Redirect.h
  * 
- * SAML 2.0 HTTP Redirect compression functionality
+ * SAML 2.0 HTTP Redirect compression functionality.
  */
 
 #include "internal.h"
@@ -56,7 +60,7 @@ char* opensaml::saml2p::deflate(char* in, unsigned int in_len, unsigned int* out
     
     z.zalloc = saml_zalloc;
     z.zfree = saml_zfree;
-    z.opaque = NULL;
+    z.opaque = nullptr;
     z.next_in = (Bytef*)in;
     z.avail_in = in_len;
     *out_len = 0;
@@ -64,7 +68,7 @@ char* opensaml::saml2p::deflate(char* in, unsigned int in_len, unsigned int* out
     int ret = deflateInit2(&z, 9, Z_DEFLATED, -15, 9, Z_DEFAULT_STRATEGY);
     if (ret != Z_OK) {
         log.error("zlib deflateInit2 failed with error code (%d)", ret);
-        return NULL;
+        return nullptr;
     }
   
     int dlen = in_len + (in_len >> 8) + 12;  /* orig_size * 1.001 + 12 */
@@ -96,7 +100,7 @@ unsigned int opensaml::saml2p::inflate(char* in, unsigned int in_len, ostream& o
     
     z.zalloc = saml_zalloc;
     z.zfree = saml_zfree;
-    z.opaque = NULL;
+    z.opaque = nullptr;
     z.next_in = (Bytef*)in;
     z.avail_in = in_len;
   
