@@ -30,6 +30,8 @@
 #include <saml/base.h>
 
 #include <vector>
+#include <iostream>
+#include <boost/ptr_container/ptr_vector.hpp>
 #include <xmltooling/exceptions.h>
 #include <xmltooling/security/CredentialResolver.h>
 
@@ -49,6 +51,7 @@ namespace opensaml {
         class SAML_API RoleDescriptor;
         class SAML_API MetadataCredentialResolver;
         class SAML_API MetadataFilter;
+        class SAML_API MetadataFilterContext;
 
 #if defined (_MSC_VER)
         #pragma warning( push )
@@ -95,6 +98,13 @@ namespace opensaml {
              */
             virtual ~MetadataProvider();
 
+            /**
+             * Returns an identifier for the provider for logging/status purposes.
+             *
+             * @return an identifier, or null
+             */
+            virtual const char* getId() const;
+
             /**
              * Adds a metadata filter to apply to any resolved metadata. Will not be applied
              * to metadata that is already loaded.
@@ -111,6 +121,15 @@ namespace opensaml {
              */
             virtual MetadataFilter* removeMetadataFilter(MetadataFilter* oldFilter);
 
+            /**
+             * Sets a filtering context object for use by the filtering process.
+             * <p>The object's lifetime must last for the duration of the lifetime
+             * of the MetadataProvider.
+             *
+             * @param ctx   a context object
+             */
+            void setContext(const MetadataFilterContext* ctx);
+
             /**
              * Should be called after instantiating provider and adding filters, but before
              * performing any lookup operations. Allows the provider to defer initialization
@@ -120,6 +139,14 @@ namespace opensaml {
              */
             virtual void init()=0;
 
+            /**
+             * Generate an XML representation of the provider's status. The XML must be
+             * well-formed, but is otherwise arbitrary.
+             *
+             * @param os    stream to write status information to
+             */
+            virtual void outputStatus(std::ostream& os) const;
+
             /**
              * Gets the entire metadata tree, after the registered filter has been applied.
              * The caller MUST unlock the provider when finished with the data.
@@ -234,7 +261,8 @@ namespace opensaml {
             void doFilters(xmltooling::XMLObject& xmlObject) const;
 
         private:
-            std::vector<MetadataFilter*> m_filters;
+            const MetadataFilterContext* m_filterContext;
+            boost::ptr_vector<MetadataFilter> m_filters;
         };
 
 #if defined (_MSC_VER)
@@ -255,6 +283,9 @@ namespace opensaml {
         /** MetadataProvider that wraps a sequence of metadata providers. */
         #define CHAINING_METADATA_PROVIDER  "Chaining"
 
+        /** MetadataProvider that loads a directory of files. */
+        #define FOLDER_METADATA_PROVIDER  "Folder"
+
         /** MetadataProvider that returns an empty "dummy" entity descriptor. */
         #define NULL_METADATA_PROVIDER  "Null"
 
