@@ -33,6 +33,9 @@
 #include "saml2/metadata/MetadataCredentialCriteria.h"
 
 #include <memory>
+#include <functional>
+#include <boost/bind.hpp>
+#include <boost/ptr_container/ptr_vector.hpp>
 #include <xercesc/util/XMLUniDefs.hpp>
 #include <xmltooling/logging.h>
 #include <xmltooling/util/Threads.h>
@@ -44,6 +47,7 @@ using namespace opensaml;
 using namespace xmlsignature;
 using namespace xmltooling::logging;
 using namespace xmltooling;
+using namespace boost;
 using namespace std;
 
 namespace opensaml {
@@ -63,13 +67,15 @@ namespace opensaml {
 
             Lockable* lock();
             void unlock();
+            void setContext(const MetadataFilterContext*);
             void init();
+            void outputStatus(ostream&) const;
             const XMLObject* getMetadata() const;
-            const EntitiesDescriptor* getEntitiesDescriptor(const char* name, bool requireValidMetadata=true) const;
-            pair<const EntityDescriptor*,const RoleDescriptor*> getEntityDescriptor(const Criteria& criteria) const;
+            const EntitiesDescriptor* getEntitiesDescriptor(const char*, bool requireValidMetadata=true) const;
+            pair<const EntityDescriptor*,const RoleDescriptor*> getEntityDescriptor(const Criteria&) const;
     
             const Credential* resolve(const CredentialCriteria* criteria=nullptr) const;
-            vector<const Credential*>::size_type resolve(vector<const Credential*>& results, const CredentialCriteria* criteria=nullptr) const;
+            vector<const Credential*>::size_type resolve(vector<const Credential*>&, const CredentialCriteria* criteria=nullptr) const;
 
             string getCacheTag() const {
                 Lock lock(m_trackerLock);
@@ -80,8 +86,8 @@ namespace opensaml {
                 if (wrapArray)
                     os << '[';
                 // Lock each provider in turn and suck in its feed.
-                for (vector<MetadataProvider*>::const_iterator m = m_providers.begin(); m != m_providers.end(); ++m) {
-                    DiscoverableMetadataProvider* d = dynamic_cast<DiscoverableMetadataProvider*>(*m);
+                for (ptr_vector<MetadataProvider>::iterator m = m_providers.begin(); m != m_providers.end(); ++m) {
+                    DiscoverableMetadataProvider* d = dynamic_cast<DiscoverableMetadataProvider*>(&(*m));
                     if (d) {
                         Locker locker(d);
                         d->outputFeed(os, first, false);
@@ -106,9 +112,9 @@ namespace opensaml {
 
         private:
             bool m_firstMatch;
-            mutable Mutex* m_trackerLock;
-            ThreadKey* m_tlsKey;
-            vector<MetadataProvider*> m_providers;
+            mutable auto_ptr<Mutex> m_trackerLock;
+            auto_ptr<ThreadKey> m_tlsKey;
+            mutable ptr_vector<MetadataProvider> m_providers;
             mutable set<tracker_t*> m_trackers;
             static void tracker_cleanup(void*);
             Category& m_log;
@@ -171,7 +177,7 @@ void ChainingMetadataProvider::tracker_cleanup(void* ptr)
 }
 
 ChainingMetadataProvider::ChainingMetadataProvider(const DOMElement* e)
-    : ObservableMetadataProvider(e), m_firstMatch(true), m_trackerLock(nullptr), m_tlsKey(nullptr),
+    : ObservableMetadataProvider(e), m_firstMatch(true), m_trackerLock(Mutex::create()), m_tlsKey(ThreadKey::create(tracker_cleanup)),
         m_log(Category::getInstance(SAML_LOGCAT".Metadata.Chaining"))
 {
     if (XMLString::equals(e ? e->getAttributeNS(nullptr, precedence) : nullptr, last))
@@ -190,31 +196,35 @@ ChainingMetadataProvider::ChainingMetadataProvider(const DOMElement* e)
                 m_providers.push_back(provider.get());
                 provider.release();
             }
-            catch (exception& ex) {
+            catch (std::exception& ex) {
                 m_log.error("error building MetadataProvider: %s", ex.what());
             }
         }
+        else {
+            m_log.error("MetadataProvider element missing type attribute");
+        }
         e = XMLHelper::getNextSiblingElement(e, _MetadataProvider);
     }
-    m_trackerLock = Mutex::create();
-    m_tlsKey = ThreadKey::create(tracker_cleanup);
 }
 
 ChainingMetadataProvider::~ChainingMetadataProvider()
 {
-    delete m_tlsKey;
-    delete m_trackerLock;
+    m_tlsKey.reset();   // need to free this ahead of trackers in a command line case
     for_each(m_trackers.begin(), m_trackers.end(), xmltooling::cleanup<tracker_t>());
-    for_each(m_providers.begin(), m_providers.end(), xmltooling::cleanup<MetadataProvider>());
+}
+
+void ChainingMetadataProvider::setContext(const MetadataFilterContext* ctx)
+{
+    for_each(m_providers.begin(), m_providers.end(), boost::bind(&MetadataProvider::setContext, _1, ctx));
 }
 
 void ChainingMetadataProvider::init()
 {
-    for (vector<MetadataProvider*>::const_iterator i=m_providers.begin(); i!=m_providers.end(); ++i) {
+    for (ptr_vector<MetadataProvider>::iterator i = m_providers.begin(); i != m_providers.end(); ++i) {
         try {
-            (*i)->init();
+            i->init();
         }
-        catch (exception& ex) {
+        catch (std::exception& ex) {
             m_log.crit("failure initializing MetadataProvider: %s", ex.what());
         }
     }
@@ -224,6 +234,11 @@ void ChainingMetadataProvider::init()
     m_feedTag = SAMLArtifact::toHex(m_feedTag);
 }
 
+void ChainingMetadataProvider::outputStatus(ostream& os) const
+{
+    for_each(m_providers.begin(), m_providers.end(), boost::bind(&MetadataProvider::outputStatus, _1, boost::ref(os)));
+}
+
 Lockable* ChainingMetadataProvider::lock()
 {
     return this;   // we're not lockable ourselves...
@@ -235,7 +250,7 @@ void ChainingMetadataProvider::unlock()
     void* ptr=m_tlsKey->getData();
     if (ptr) {
         tracker_t* t = reinterpret_cast<tracker_t*>(ptr);
-        for_each(t->m_locked.begin(), t->m_locked.end(), mem_fun<void,Lockable>(&Lockable::unlock));
+        for_each(t->m_locked.begin(), t->m_locked.end(), mem_fun(&Lockable::unlock));
         t->m_locked.clear();
         t->m_objectMap.clear();
     }
@@ -262,13 +277,13 @@ const EntitiesDescriptor* ChainingMetadataProvider::getEntitiesDescriptor(const
     MetadataProvider* held = nullptr;
     const EntitiesDescriptor* ret = nullptr;
     const EntitiesDescriptor* cur = nullptr;
-    for (vector<MetadataProvider*>::const_iterator i=m_providers.begin(); i!=m_providers.end(); ++i) {
-        tracker->lock_if(*i);
-        if (cur=(*i)->getEntitiesDescriptor(name,requireValidMetadata)) {
+    for (ptr_vector<MetadataProvider>::iterator i = m_providers.begin(); i != m_providers.end(); ++i) {
+        tracker->lock_if(&(*i));
+        if ((cur = i->getEntitiesDescriptor(name,requireValidMetadata))) {
             // Are we using a first match policy?
             if (m_firstMatch) {
                 // Save locked provider.
-                tracker->remember(*i);
+                tracker->remember(&(*i));
                 return cur;
             }
 
@@ -279,12 +294,12 @@ const EntitiesDescriptor* ChainingMetadataProvider::getEntitiesDescriptor(const
             }
 
             // Save off the latest match.
-            held = *i;
+            held = &(*i);
             ret = cur;
         }
         else {
             // No match, so just unlock this one and move on.
-            tracker->unlock_if(*i);
+            tracker->unlock_if(&(*i));
         }
     }
 
@@ -311,9 +326,9 @@ pair<const EntityDescriptor*,const RoleDescriptor*> ChainingMetadataProvider::ge
     MetadataProvider* held = nullptr;
     pair<const EntityDescriptor*,const RoleDescriptor*> ret = pair<const EntityDescriptor*,const RoleDescriptor*>(nullptr,nullptr);
     pair<const EntityDescriptor*,const RoleDescriptor*> cur = ret;
-    for (vector<MetadataProvider*>::const_iterator i=m_providers.begin(); i!=m_providers.end(); ++i) {
-        tracker->lock_if(*i);
-        cur = (*i)->getEntityDescriptor(criteria);
+    for (ptr_vector<MetadataProvider>::iterator i = m_providers.begin(); i != m_providers.end(); ++i) {
+        tracker->lock_if(&(*i));
+        cur = i->getEntityDescriptor(criteria);
         if (cur.first) {
             if (criteria.role) {
                 // We want a role also. Did we find one?
@@ -324,7 +339,7 @@ pair<const EntityDescriptor*,const RoleDescriptor*> ChainingMetadataProvider::ge
                         if (held)
                             tracker->unlock_if(held);
                         // Save locked provider and role mapping.
-                        tracker->remember(*i, cur.first);
+                        tracker->remember(&(*i), cur.first);
                         return cur;
                     }
 
@@ -350,7 +365,7 @@ pair<const EntityDescriptor*,const RoleDescriptor*> ChainingMetadataProvider::ge
                     }
 
                     // Save off the latest match.
-                    held = *i;
+                    held = &(*i);
                     ret = cur;
                 }
                 else {
@@ -358,13 +373,13 @@ pair<const EntityDescriptor*,const RoleDescriptor*> ChainingMetadataProvider::ge
                     // but save this one if we didn't have the role yet.
                     if (ret.second) {
                         // We already had a role, so let's stick with that.
-                        tracker->unlock_if(*i);
+                        tracker->unlock_if(&(*i));
                     }
                     else {
                         // This is at least as good, so toss anything we had and keep it.
                         if (held)
                             tracker->unlock_if(held);
-                        held = *i;
+                        held = &(*i);
                         ret = cur;
                     }
                 }
@@ -377,7 +392,7 @@ pair<const EntityDescriptor*,const RoleDescriptor*> ChainingMetadataProvider::ge
                         tracker->unlock_if(held);
                     
                     // Save locked provider.
-                    tracker->remember(*i, cur.first);
+                    tracker->remember(&(*i), cur.first);
                     return cur;
                 }
 
@@ -398,13 +413,13 @@ pair<const EntityDescriptor*,const RoleDescriptor*> ChainingMetadataProvider::ge
                 }
 
                 // Save off the latest match.
-                held = *i;
+                held = &(*i);
                 ret = cur;
             }
         }
         else {
             // No match, so just unlock this one and move on.
-            tracker->unlock_if(*i);
+            tracker->unlock_if(&(*i));
         }
     }
 
