@@ -1,17 +1,21 @@
-/*
- *  Copyright 2001-2008 Internet2
- * 
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+/**
+ * Licensed to the University Corporation for Advanced Internet
+ * Development, Inc. (UCAID) under one or more contributor license
+ * agreements. See the NOTICE file distributed with this work for
+ * additional information regarding copyright ownership.
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ * UCAID licenses this file to you under the Apache License,
+ * Version 2.0 (the "License"); you may not use this file except
+ * in compliance with the License. You may obtain a copy of the
+ * License at
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
+ * either express or implied. See the License for the specific
+ * language governing permissions and limitations under the License.
  */
 
 /**
@@ -58,14 +62,9 @@ namespace opensaml {
 
 static const XMLCh maxValidityInterval[] =  UNICODE_LITERAL_19(m,a,x,V,a,l,i,d,i,t,y,I,n,t,e,r,v,a,l);
 
-RequireValidUntilMetadataFilter::RequireValidUntilMetadataFilter(const DOMElement* e) : m_maxValidityInterval(60 * 60 * 24 * 7)
+RequireValidUntilMetadataFilter::RequireValidUntilMetadataFilter(const DOMElement* e)
+    : m_maxValidityInterval(XMLHelper::getAttrInt(e, 60 * 60 * 24 * 7, maxValidityInterval))
 {
-    const XMLCh* mvi = e ? e->getAttributeNS(NULL,maxValidityInterval) : NULL;
-    if (mvi && *mvi) {
-        m_maxValidityInterval = XMLString::parseInt(mvi);
-        if (m_maxValidityInterval == 0)
-            m_maxValidityInterval = 60 * 60 * 24 * 7;
-    }
 }
 
 void RequireValidUntilMetadataFilter::doFilter(XMLObject& xmlObject) const
@@ -77,6 +76,6 @@ void RequireValidUntilMetadataFilter::doFilter(XMLObject& xmlObject) const
     if (!tbo->getValidUntil())
         throw MetadataFilterException("Metadata did not include a validUntil attribute.");
 
-    if (tbo->getValidUntilEpoch() - time(NULL) > m_maxValidityInterval)
+    if (tbo->getValidUntilEpoch() - time(nullptr) > m_maxValidityInterval)
         throw MetadataFilterException("Metadata validity interval is larger than permitted.");
 }
