@@ -1,17 +1,21 @@
-/*
- *  Copyright 2001-2009 Internet2
- * 
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+/**
+ * Licensed to the University Corporation for Advanced Internet
+ * Development, Inc. (UCAID) under one or more contributor license
+ * agreements. See the NOTICE file distributed with this work for
+ * additional information regarding copyright ownership.
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ * UCAID licenses this file to you under the Apache License,
+ * Version 2.0 (the "License"); you may not use this file except
+ * in compliance with the License. You may obtain a copy of the
+ * License at
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
+ * either express or implied. See the License for the specific
+ * language governing permissions and limitations under the License.
  */
 
 #include "internal.h"
@@ -59,20 +63,20 @@ public:
     void testSingleElementUnmarshall() {
         auto_ptr<XMLObject> xo(unmarshallElement(singleElementFile));
         KeyInfoConfirmationDataType* scd = dynamic_cast<KeyInfoConfirmationDataType*>(xo.get());
-        TS_ASSERT(scd!=NULL);
+        TS_ASSERT(scd!=nullptr);
 
-        TS_ASSERT(scd->getNotBefore()==NULL);
-        TS_ASSERT(scd->getNotOnOrAfter()==NULL);
-        TS_ASSERT(scd->getRecipient()==NULL);
-        TS_ASSERT(scd->getInResponseTo()==NULL);
-        TS_ASSERT(scd->getAddress()==NULL);
+        TS_ASSERT(scd->getNotBefore()==nullptr);
+        TS_ASSERT(scd->getNotOnOrAfter()==nullptr);
+        TS_ASSERT(scd->getRecipient()==nullptr);
+        TS_ASSERT(scd->getInResponseTo()==nullptr);
+        TS_ASSERT(scd->getAddress()==nullptr);
         TSM_ASSERT_EQUALS("# of KeyInfo child elements", 0, scd->getKeyInfos().size());
     }
 
     void testSingleElementOptionalAttributesUnmarshall() {
         auto_ptr<XMLObject> xo(unmarshallElement(singleElementOptionalAttributesFile));
         KeyInfoConfirmationDataType* scd = dynamic_cast<KeyInfoConfirmationDataType*>(xo.get());
-        TS_ASSERT(scd!=NULL);
+        TS_ASSERT(scd!=nullptr);
 
         TSM_ASSERT_EQUALS("NotBefore attribute", expectedNotBefore->getEpoch(), scd->getNotBefore()->getEpoch());
         TSM_ASSERT_EQUALS("NotOnOrAfter attribute", expectedNotOnOrAfter->getEpoch(), scd->getNotOnOrAfter()->getEpoch());
@@ -87,13 +91,13 @@ public:
     void testChildElementsUnmarshall() {
         auto_ptr<XMLObject> xo(unmarshallElement(childElementsFile));
         KeyInfoConfirmationDataType* scd= dynamic_cast<KeyInfoConfirmationDataType*>(xo.get());
-        TS_ASSERT(scd!=NULL);
+        TS_ASSERT(scd!=nullptr);
 
-        TS_ASSERT(scd->getNotBefore()==NULL);
-        TS_ASSERT(scd->getNotOnOrAfter()==NULL);
-        TS_ASSERT(scd->getRecipient()==NULL);
-        TS_ASSERT(scd->getInResponseTo()==NULL);
-        TS_ASSERT(scd->getAddress()==NULL);
+        TS_ASSERT(scd->getNotBefore()==nullptr);
+        TS_ASSERT(scd->getNotOnOrAfter()==nullptr);
+        TS_ASSERT(scd->getRecipient()==nullptr);
+        TS_ASSERT(scd->getInResponseTo()==nullptr);
+        TS_ASSERT(scd->getAddress()==nullptr);
         TSM_ASSERT_EQUALS("# of KeyInfo child elements", 1, scd->getKeyInfos().size());
 
         //TODO need to test with some wildcard child elements
